def add(a: str, b: str):
    """
    입력받은 두 정수를 더하는 함수입니다.

    :param a: 첫 번째 정수
    :param b: 두 번째 정수
    :return: 두 정수와 두 정수의 합을 반환합니다.
    :rtype: int
    """
    a_int = int(a)
    b_int = int(b)
    result = a_int + b_int
    return result



from setuptools import setup, find_packages

setup(
    name="nemoai_package",
    version="0.1.1",
    packages=find_packages(),
    install_requires=[
        "fastapi",
        "uvicorn",
        "sphinx",
        "twine",
        "setuptools",
    ],
)
